@@ -5,6 +5,10 @@ from typing import Iterable, Optional
 from urllib.parse import unquote
 
 from botocore.exceptions import ClientError
+from loguru import logger
+from mypy_boto3_s3 import S3Client
+from mypy_boto3_s3.type_defs import ObjectTypeDef
+
 from gable.cli.helpers.data_asset_s3.compression_handler import CompressionHandler
 from gable.cli.helpers.data_asset_s3.logger import log_debug, log_error, log_trace
 from gable.cli.helpers.data_asset_s3.path_pattern_manager import (
@@ -16,9 +20,6 @@ from gable.cli.helpers.data_asset_s3.path_pattern_manager import (
 )
 from gable.cli.helpers.emoji import EMOJI
 from gable.cli.helpers.logging import log_execution_time
-from loguru import logger
-from mypy_boto3_s3 import S3Client
-from mypy_boto3_s3.type_defs import ObjectTypeDef
 
 
 @log_execution_time
@@ -133,14 +134,9 @@ def _discover_file_paths_from_s3_bucket(
         log_trace_with_prefix(prefix, "Excluded by exclude pattern")
         return
     try:
-        files = list(
-            filter(
-                is_supported_file_type,
-                [
-                    obj["Key"] for obj in _list_files(client, bucket_name, max_ls_results, prefix)  # type: ignore
-                ],
-            )
-        )
+        files = [
+            obj["Key"] for obj in _list_files(client, bucket_name, max_ls_results, prefix)  # type: ignore
+        ]
 
         # If we're in a month, day, hour, or minute folder, check for files and add them regardless of the name
         if files and any([month, day, hour, minute]):
@@ -681,6 +677,8 @@ def _list_files(
         PaginationConfig={"MaxItems": max_files},
     ):
         for obj in page.get("Contents", []):
+            if obj.get("Size", 0) == 0:
+                continue
             files.append(obj)
     log_trace_with_prefix(
         prefix, f"Completed listing files, total files gathered: {len(files)}"
@@ -695,7 +693,9 @@ def is_supported_file_type(file_path: str) -> bool:
     """
     return any(
         file_path.endswith(file_type)
-        or CompressionHandler.get_original_format(file_path).endswith(file_type)
+        or CompressionHandler.get_original_format(file_path).extension.endswith(
+            file_type
+        )
         for file_type in SUPPORTED_FILE_TYPES_SET
     )
 
